==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/block/entity/GensokyoAltarBlockEntity.java <==
package cc.thonly.reverie_dreams.block.entity;

import cc.thonly.polymer.block.GensokyoAltarImpl;
import lombok.Getter;
import net.minecraft.class_11368;
import net.minecraft.class_11372;
import net.minecraft.class_1262;
import net.minecraft.class_1277;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_2586;
import net.minecraft.class_2680;

@Getter
public class GensokyoAltarBlockEntity extends class_2586 {
    private class_1277 inventory = new class_1277(9);
    public int tick = 0;

    public GensokyoAltarBlockEntity(class_2338 pos, class_2680 state) {
        super(ModBlockEntities.GENSOKYO_ALTAR_BLOCK_ENTITY, pos, state);
    }

    public static void tick(class_1937 world, class_2338 pos, class_2680 state, GensokyoAltarBlockEntity blockEntity) {
        if (blockEntity.tick > 5) {
            GensokyoAltarImpl.Model altarModel = GensokyoAltarImpl.STATE_TO_MODEL.get(state);
            if (altarModel != null) {
                altarModel.update();
            }
            blockEntity.tick = 0;
        }
        GensokyoAltarImpl.Model altarModel = GensokyoAltarImpl.STATE_TO_MODEL.get(state);
        if (altarModel != null) {
            altarModel.angle += 2f;
            if (altarModel.angle >= 360) {
                altarModel.angle = 0;
            }
        }
        blockEntity.tick++;
    }

    @Override
    protected void method_11007(class_11372 view) {
        super.method_11007(view);
        class_1262.method_5426(view, inventory.field_5828);
    }

    @Override
    protected void method_11014(class_11368 view) {
        super.method_11014(view);
        class_1277 inventory = new class_1277(9);
        class_1262.method_5429(view, inventory.field_5828);
        this.inventory = inventory;
    }

}

==> reverie_dreams-0.4.6%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/block/entity/GensokyoAltarBlockEntity.java <==
package cc.thonly.reverie_dreams.block.entity;

import cc.thonly.polymer.block.GensokyoAltarImpl;
import lombok.Getter;
import net.minecraft.class_11368;
import net.minecraft.class_11372;
import net.minecraft.class_1262;
import net.minecraft.class_1277;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_2586;
import net.minecraft.class_2680;

@Getter
public class GensokyoAltarBlockEntity extends class_2586 {
    private class_1277 inventory = new class_1277(9);
    public int tick = 0;

    public GensokyoAltarBlockEntity(class_2338 pos, class_2680 state) {
        super(RDBlockEntityTypes.GENSOKYO_ALTAR_BLOCK_ENTITY, pos, state);
    }

    public static void tick(class_1937 world, class_2338 pos, class_2680 state, GensokyoAltarBlockEntity blockEntity) {
        if (blockEntity.tick > 5) {
            GensokyoAltarImpl.Model altarModel = GensokyoAltarImpl.STATE_TO_MODEL.get(state);
            if (altarModel != null) {
                altarModel.update();
            }
            blockEntity.tick = 0;
        }
        GensokyoAltarImpl.Model altarModel = GensokyoAltarImpl.STATE_TO_MODEL.get(state);
        if (altarModel != null) {
            altarModel.angle += 2f;
            if (altarModel.angle >= 360) {
                altarModel.angle = 0;
            }
        }
        blockEntity.tick++;
    }

    @Override
    protected void method_11007(class_11372 view) {
        super.method_11007(view);
        class_1262.method_5426(view, inventory.field_5828);
    }

    @Override
    protected void method_11014(class_11368 view) {
        super.method_11014(view);
        class_1277 inventory = new class_1277(9);
        class_1262.method_5429(view, inventory.field_5828);
        this.inventory = inventory;
    }

}
